\name{chisq.test}
\alias{chisq.test}
\title{Interface for Pearson's Chi-squared Test for Count Data}
\description{
  User friendly implementation of \code{\link[stats]{chisq.test}}, performs chi-squared
  contingency table tests and goodness-of-fit tests.
}
\usage{
# chisq.test()

chisq.test(x,
           y = NULL, 
           correct = TRUE,
           p = rep(1/length(x), length(x)),
           rescale.p = FALSE,
           simulate.p.value = FALSE,
           B = 2000,
           interactive = FALSE)
}
\arguments{
  If no arguments are passed, the function will enter interactive mode.
  \item{x}{a numeric vector or matrix containing the data. \code{x} and \code{y}
    can also both be factors.}
  \item{y}{a numeric vector; ignored if \code{x} is a matrix.  If
    \code{x} is a factor, \code{y} should be a factor of the same length.}
  \item{correct}{a logical indicating whether to apply continuity
    correction when computing the test statistic for 2 by 2 tables: one
    half is subtracted from all \eqn{|O - E|} differences; however, the
    correction will not be bigger than the differences themselves.  No correction
    is done if \code{simulate.p.value = TRUE}.}
  \item{p}{a vector of probabilities of the same length of \code{x}.
    An error is given if any entry of \code{p} is negative.}
  \item{rescale.p}{a logical scalar; if TRUE then \code{p} is rescaled
    (if necessary) to sum to 1.  If \code{rescale.p} is FALSE and
    \code{p} does not sum to 1, an error is given.}
  \item{simulate.p.value}{a logical indicating whether to compute
    p-values by Monte Carlo simulation.}
  \item{B}{an integer specifying the number of replicates used in the
    Monte Carlo test.}
  \item{interactive}{a logical. If TRUE, all other arguments are ignored and
  the function will enter interactive mode. Control is transferred to 
  \code{\link{function.execute.cli}}.}
}
\details{
  Takes the above input parameters and passes them to \code{\link[stats]{chisq.test}}.
  Will return a list with the following values.
}
\value{
  A list containing the following components:
  \item{test.statistic}{the value fo the chi-squared test statistic.}
  \item{p.value}{the p-value for the test.}
  \item{df}{the degrees of freedom of the approximate chi-squared distribution,
  \code{NA} if the p-value is computed by Monte-carlo simulation.}
  \item{observed}{the observed counts.}
  \item{expected}{the expected counts under the null hypothesis.}
  \item{residuals}{the Pearson residuals}
  \item{standard.residuals}{standardized residuals}
  
  Will return an object of class "try-error" if an error is encountered in \code{\link[stats]{chisq.test}}.
}
\references{
Albright, Brian. \emph{Essentials of Mathematical Statistics}. Jones & Bartlett Learning. Print.
}
\seealso{
  \code{\link[stats]{chisq.test}} for the function that implements the
  test.
}

\examples{
## Example 5.7.2 from Essentials of Mathematical Statistics
## In 1996, the colors of plain M&M candies were distributed as follows:
## 30\% brown, 20\% yellow, 20\% red, 10\% orange, 10\% green, and 10\%
## blue. Some years later, a class of statistics students tested the
## claim that the distribution has not changed. They recorded the colors
## of 1191 randomly selected plain M&M candies, as shown in the first
## two columns of table 5.8.

## Data
freq = c(154,201,156,228,205,247)
prob = c(.3,.2,.2,.1,.1,.1)

## Paramaters
## The freq data list is the number of times that the colors brown, yellow,
## red, orange, green, and blue were observed (in that order). The prob
## data list is the expected probability of finding colors (in the same
## order, as given in the problem above).

## Method
out <- chisq.test(x = freq, p = prob)

## Results
## out$test.statistic = 448.7299
## out$p.value = 9.230661e-95
## out$df = 5
## out$observed = 154 201 156 228 205 247
## out$expected = 357.3 238.2 238.2 119.1 119.1 119.1
## out$residuals = -10.755259 -2.410305 -5.325997
## 9.978655 7.871134 11.718651
## out$standard.residuals = -12.854993 -2.694803
## -5.954646 10.518426 8.296903 12.353596

## Example 5.8.1
## To determine if regular M&Ms have the same proportions of each
## color as peanut M&Ms, a student selects a randome sample of
## each type and counts the number of each color, as shown in
## table 5.18 (data collected by Rebekah Brisbois, 2009). Use
## these data to test the claim that the two types have the same
## proportion of the different colors.

## Data
table = matrix(c(62, 31, 60, 10, 68, 41, 98, 13, 45, 12, 84, 35),
nrow=2, ncol=6)

## Parameters
## For a test of independence, correct is FALSE.

## Method
out <- chisq.test(table, correct = FALSE)

## Results
## out$test.statistic = 28.78854
## out$p.value = 2.551076e-05
## out$df = 5
## out$observed = 62 31 60 10 68 41 98 13 45 12 85 35
## out$expected = 69.37567 23.62433 52.21825 17.78175 81.31127 27.68873
## 82.80322 28.19678 42.52057 14.47943 88.77102 30.22898
## out$residuals = -0.8855191 1.5174758 1.0768775 -1.8453985
## -1.4761963 2.5296939 1.6700442 -2.8618826 0.3802348
## -0.6515920 -0.5063789 0.8677597
## out$standard.residuals = -1.924299  1.924299  2.284439 -2.284439
## -3.264416  3.264416  3.701320 -3.701320  0.796100 -0.796100 
## -1.132444  1.132444
}
\keyword{htest}
