\name{interactive.cli}
\alias{interactive.cli}
\alias{cli}
\title{Interactive Hypothesis Testing (Command Line Interface)}
\description{
  Helps the user to decide which function is appropriate and executes that function on the user's behalf through \link{execute.cli}.
  Operates through the R console in a command line interface mode.
}
\usage{
interactive.cli(Which_Statistic = NULL,
                Sigma_or_Prob_Known = NULL,
                Sum_or_Data = NULL,
                Num_Samples = NULL,
                Small_or_Large = NULL, 
                Dep_or_Indep = NULL)
}
\arguments{
  All arguments are optional. The user will be prompted if any required information is missing or incorrectly supplied.
  In all character strings, the first letter must be capitalized.
  
  \item{Which_Statistic}{either \code{NULL} or a character string which determines
  the type of statistical test that will be carried out. Character strings may take
  one of the following values: "Mean", "Mu", "Sigma", "Variance", Variance Ratio", "Var",
  "Regression", "Proportion", "Prop", "Independence", "Indep", "Fitness",
  "Distribution", or "Distro".}
  \item{Sigma_or_Prob_Known}{either \code{NULL} or a logical or a character string 
  which determines if either sigma (quantitative data) or the probabilities
  (categorical data) are known. Character strings and logicals may take on one of 
  the following values: "Yes", \code{TRUE}, "No", \code{FALSE}.}
  \item{Sum_or_Data}{either \code{NULL} or a character string which determines if there
  are summary statistics or data. Character strings may take on one of the following
  values: "Sum" or "Data".}
  \item{Num_Samples}{either \code{NULL}, a logical, or a character string which determines
  the number of samples. Character strings and logicals may take on one of the following
  values: "1", "2", "Many", "TRUE", or "FALSE" A logical is only used when \code{Which_Statistic}="Mu".}
  \item{Small_or_Large}{either \code{NULL} or a character string which determines if
  there is small or large sample data. Character strings may take on one of the following
  values: "Small" or "Large".}
  \item{Dep_or_Indep}{either \code{NULL} or a character string which determines if
  the data is dependent or independent. Character strings may take on one of the following
  values: "Dep" or "Indep".}
}
\details{
  If none or some of the arguments are provided (correctly or incorrectly),
  the user will be prompted with questions to fill in the missing information until sufficient
  information is available to execute a test.
  
  If sufficient information is available to execute a statistics test, \code{\link{execute.cli}}
  will be called to take function specific parameters and pass them to the appropriate statistical test.
}
\value{
  In addition to interactive prompts, the name of the executed statistical test will be written to the console.
  
  Upon user exit, the return value will be the results of all statistical function called
  in addition to the names of the functions called preceeding the results of the statistical test.
  If an interactively supported function is called, the output will be a list that typically
  contains, but does not always contain, the following components:
  \item{test.statistic}{the test statistic of the specific test.}
  \item{p.value}{the p-value for the test}
  \item{alternative}{the alternative hypothesis.}
  \item{decision}{gives hypothesis decision based on the \code{p.value} and the \code{conf.level}.}
  \item{conf.int}{a confidence interval for the probability of success.}
}

\seealso{
  \code{\link{execute.cli}} for the function that takes function specific arguments and
  passes them to their respective functions.
  You can see an overview of the functions with this pdf: \url{../doc/flowchart.pdf}.
}
\examples{
\dontrun{
## The following uses Example 5.6.3 presented in the documentation for t.test.

## Data Stored in Global Environment
begin = c(77.6, 86.1, 62.1, 93.1, 74.6, 42, 86.9, 79.3, 80.2)
end = c(85.4, 83.2, 64.2, 96.6, 79.3, 40.5, 87.2, 89.2, 85.6)

## Parameters
## Since we already know the name of the function, it would be better to run
## execute.cli("t.test"). However, for demonstration, we will first assume that
## we do not know the name of the statistical test that we need. Thus, we will
## not use any of the available parameters.

## Method 1
out <- interactive.cli()

## Interactive Session
## To distinguish between user input and computer prompts, user input will be labelled "Input: "
## on the line immediately after the corresponding prompt. Comments are added to explain a
## particular subject and are labelled "Comment: ".

## Press escape key at any time to exit.
##
## Please be aware that all input is case sensitive.
##
## What kind of test do you want (Mean/Sigma/Var/Regression/Prop/Indep/Fitness/Distro):
## Input: Mean
## Do you have more than 2 samples (Yes/No)
## Input: No
## Do you know sigma or the probabilities? (Yes/No)

## Comment: This question is context dependent. If we were dealing with 
## categorical data we could be dealing with probabilities. If you know 
## EITHER sigma OR probabilities, you should answer yes to this question.
## Since we know neither for this problem, we will answer no.

## Input: No
## Do you have summary statistics or data (Sum/Data): 
## Input: Data
## The name of the test is t.test.

## Comment: Note that at this point, you should now be seeing help documentation
## on the function t.test. Also note that control has been transferred to
## execute.cli.

## Press escape key at any time to exit.
## 
## Please be aware that all input is case sensitive.
##
##
## You can create your own vector, load from a file, or use one in the
## global environment.
##
## For this: Enter the data:
## Do you want to create your own, load from a csv file, or use one in the
## global environment (C/L/G)?
## Input: G
##
## Enter the name of the value in the global environment: Enter the data:
## Input: end


## Comment: Please refer to the t.test documentation for the reason why "end"
## goes into the first data slot.


## Yes/No/TRUE/FALSE: Do you have a second set of data?
## Input: TRUE
##
## You can create your own vector, load from a file, or use one in the
## global environment.
## 
## For this: Enter the second set of data:
## Do you want to create your own, load from a csv file, or use one in the
## global environment (C/L/G)?
## Input: G
##
## Enter the name of the value in the global environment: Enter the second
## set of data: 
## Input: begin

## Enter the hypothesized mean (this is the null hypothesis):
## Input: 0
## What is the alternative hypothesis ("two.sided", "greater", "less"):
## Input: greater
## Do you have dependent data (also known as paired data)? (Yes/No)
## Input: TRUE
## Are the variances equal? (Yes/No)
## Input: No
## What is the confidence level (a decimal between 0 and 1):
## 0.95

## Comment: At this point, control is transferred to t.test.


## $test.static
## [1] 2.317183
##
## $p.value
## [1] 0.024567183
##
## $alternative
## [1] "greater"
##
## $decision
## "Reject Null (accept alternative)"
##
## $conf.int
## [1] 0.6429602    Inf
##
## Yes/No/TRUE/FALSE: Do you want to exit? If you want to change the statistical test,
## there is no need to exit.

## Comment: We will be using t.test for the Method 2, however we do not have a chance
## to put arguments into the function at this time. Therefore, you can exit here to
## run Method 2. Or, if you rerun the program and enter everything in exactly the 
## same as you did above, you will get the output presented at the end of the examples.

## Comment: If continuing:

## Input: No
## Do you want to perform the same statistical test? (Yes/No)
## Input: Yes

## Comment: If stopping:

## Input: Yes


## Method 2
## We know that we are dealing with means and that we have data (not summary statistics).
## We also know that we are conducting a 2 sample test. This is almost enough information
## to decide which statistics function to execute. We can put in whatever amount of
## information we desire, and the prompts that we get will change accordingly.

out <- interactive.cli(Which_Statistic = "Mean", Sum_or_Data = "Data", Num_Samples = 2)

## Interactive Session
## To distinguish between user input and computer prompts, user input will be labelled "Input: "
## on the line immediately after the corresponding prompt. Comments are added to explain a
## particular subject and are labelled "Comment: ".

## Yes/No/TRUE/FALSE: Do you know sigma or do you know the probabilities?
## Input: FALSE
## The name of the test is t.test

## Comment: From this point on, the interactive session will run the same way
## for the same problem. Of course, different problems could be run the same way.
## Note that even in interactive mode, the user must still know enough about
## the problem at hand to either supply the parameters or answer the questions
## in order for the right statistical test to be executed. In addition, the user
## must also know the information to pass to the statistical function parameters.

## Comment: If you reran interactive.cli and then exited, your return value
## will look like the following:

## [[1]]
## [1] "t.test"

## $test.statistic
## [1] 2.317183

## $p.value
## [1] 0.02456751

## $alternative
## [1] "greater"

## $decision
## [1] "Reject Null (accept alternative)"

## $conf.int
## [1] 0.6429602       Inf

## [[7]]
## [1] "t.test"

## $test.statistic
## [1] 2.317183

## $p.value
## [1] 0.02456751

## $alternative
## [1] "greater"

## $decision
## [1] "Reject Null (accept alternative)"

## $conf.int
## [1] 0.6429602       Inf

}
}
\keyword{interactive}
