\name{prop.test}
\alias{prop.test}
\title{Interface for Test of Equal or Given Proportions}
\description{
  User friendly implementation of \code{\link[stats]{prop.test}}.
  \code{prop.test} can be used for testing the null that the
  proportions (probabilities of success) in several groups are the
  same, or that they equal certain given values.}
\usage{
# prop.test()

prop.test(x,
          n = NULL,
          p = 0.5,
          alternative = "two.sided",
          conf.level = 0.95,
          correct = TRUE,
          interactive = FALSE)
}
\arguments{
  If no arguments are passed, the function will enter interactive mode. Interactive mode does not support tables.
  \item{x}{a vector of counts of successes, a one-dimensional table with
    two entries, or a two-dimensional table (or matrix) with 2 columns,
    giving the counts of successes and failures, respectively.}
  \item{n}{a vector of counts of trials; ignored if \code{x} is a
    matrix or a table.}
  \item{p}{a vector of probabilities of success. The length of
    \code{p} must be the same as the number of groups specified by
    \code{x}, and its elements must be greater than 0 and less than 1.}
  \item{alternative}{indicates the alternative hypothesis and must be
    one of \code{"two.sided"}, \code{"greater"} or \code{"less"}.}
  \item{conf.level}{a number between 0 and 1 that is the confidence level
    of the test.}
  \item{correct}{a logical indicating whether Yates' continuity
    correction should be applied where possible.}
  \item{interactive}{a logical. If TRUE, all other arguments are ignored and
  the function will enter interactive mode. Control is transferred to 
  \code{\link{function.execute.cli}}.}
}

\details{
  Takes the above input parameters and passes them to \code{\link[stats]{prop.test}}.
  Will return a list with the following values.
}
\value{
  A list containing the following
  components:
  \item{test.statistic}{the value of Pearson's chi-squared test statistic.}
  \item{p.value}{the p-value for the test}
  \item{alternative}{the alternative hypothesis given in \code{alternative}.}
  \item{decision}{gives hypothesis decision based on the \code{p.value} and \code{conf.level}.}
  \item{conf.int}{a confidence interval for the true proportion if
    there is one group, or for the difference in proportions if
    there are 2 groups and \code{p} is not given, or \code{NULL}
    otherwise.}
    
  Will return an object of class "try-error" if an error is encountered in \code{\link[stats]{prop.test}}.
}
\references{
Albright, Brian. \emph{Essentials of Mathematical Statistics}. Jones & Bartlett Learning. Print.
}
\seealso{
  \code{\link[stats]{prop.test}} for the function that implements the
  test.
}
\examples{
## Example 5.2.1 from Essentials of Mathematical Statistics
## A student claims that 25\% of plain M&M candies are red.
## A random sample of 195 candies contains 37 red candies.
## Use these data to test the claim at the 0.05 significance level.

## Parameters
## The first sentence tells us that p = 0.25.
## The scond sentence tells us that x = 37 and n = 195.
## We want to know if there are fewer than 25\% red candies,
## therefore the alternative = "less".
## Last, 0.05 signficance level corresponds to alpha.
## The confidence level is 1 - alpha, so conf.level = 0.95.
## Yates' continuity correction is not required, so correct = F.

## Method
prop.test(37, 195, p = 0.25, alternative = "less", conf.level = 0.95, correct = FALSE)

## Results
## The results for this example are:
## out$test.statistic = 3.776068
## out$p.value = 0.02599534
## out$alternative = "less"
## out$decision = "Reject Null (accept alternative)"
## out$conf.int = 0.0000000 0.2400537

## It should be noted that the test statistic given in the book
## and the test statistic given here do not use the same formula.
## More specifically, the test statistic given here is calculated
## using the Pearson's chi-squared test statistic.


## Exercise 3 on Page 352
## In a random sample of 1008 voters who voted in the 2006 Nebraska
## governor's election, 24\% were 65 years and older. A reporter writes
## a story about this election and says, "Less than 25\% of all voters
## in this election were aged 65 years and older". Determine if the
## data support this statement.

## Parameters
## We know that n = 1008 and, in a sample, 24\% were 65 years and older.
## Thus, x = 1008 * 0.24. One may also use x = round(1008*0.24) to
## keep x an integer value. We know that p = 0.25 because this is the
## reporter's claim. The alternative hypothesis is "less".
## Because we are not given the confidence level, assume it is 0.95.
## Continuity correction is not required.

## Method
prop.test(1008*0.24, 1008, p = 0.25, alternative = "less", correct = FALSE)

## Results
## out$test.statistic = 0.5376
## out$p.value = 0.231745
## out$alternative = "less"
## out$decision = "Null Hypothesis Possible (reject alternative)"
## conf.int = 0.0000000 0.2628036

## Example 5.4.1
## In a survey of voters in the 2008 Texas Democratic primary, 54\% of 1167 females
## voted for Hillary Clinton, while 47\% of 881 males voted for Clinton (data from
## CNNPolitics.com, March 5, 2008). Use these data to test the claim that of the
## voters in the 2008 Texas Democratic primary, the proportion of females who voted
## for Clinton is higher than the proportion of males who voted for Clinton.

## Parameters
## We know that the proportion of females is 54\% and the proportion of males is
## 47\%. To get the number of "successes", we multiply the size of each sample by
## their corresponding proportion: x = c(0.54 * 1167, 0.47 * 881).
## The alternative hypothesis is "greater".

## Method
out <- prop.test(x = c(0.54*1167, 0.47*881), n = c(1167, 881), alternative = "greater")

## Results
## out$test.statistic = 9.843346
## out$p.value = 0.0008522359
## out$alternative = "greater"
## out$decision = "Reject Null (accept alternative)"
## out$conf.int = 0.03338213 1.0000000

## Warning message:
## In stats:: prop.test(x, n, p, alternative, conf.level, correct):
##  Chi-squared approximation may be incorrect
}
\keyword{htest}
